@@ -200,6 +200,9 @@ struct Window {
   size_t topdelta;
   int lastpointn;
 
+  /* The start column of the window (>0 if scrolled sideways) */
+  size_t start_column;
+
   /* The point line pointer, line number and offset (used to
      hold the point in non-current windows). */
   Marker *saved_pt;
